pub fn on_bucket_mutation(profile: &ProfileId, store: &CacheHandle)Expand description
Invalidate the Buckets listing for a profile when a bucket-level mutation
occurs (e.g. bucket created or deleted).
pub fn on_bucket_mutation(profile: &ProfileId, store: &CacheHandle)Invalidate the Buckets listing for a profile when a bucket-level mutation
occurs (e.g. bucket created or deleted).