diagnostics_export

Function diagnostics_export 

pub async fn diagnostics_export(
    bundle_ref: BundleRef,
    dest_path: PathBuf,
) -> Result<(), AppError>
Copy the collected bundle ZIP to dest_path and clean up the temp dir.

bundle_ref must be the value returned by a preceding diagnostics_collect call. After a successful export the temp dir is removed automatically.