locks_list

Function locks_list 

pub async fn locks_list(
    scope: Option<LockScopeDto>,
    registry: State<'_, LockRegistryHandle>,
) -> Result<Vec<ResourceLock>, AppError>
Return all active locks, optionally filtered to those whose scope intersects scope.

When scope is None every active lock is returned.