notification_dismiss

Function notification_dismiss 

pub async fn notification_dismiss(
    id: String,
    log: State<'_, NotificationLogHandle>,
) -> Result<bool, AppError>
Dismiss (remove) a notification by its id.

Returns true when the notification was found and removed, false when no notification with that id exists.