multipart_abort

Function multipart_abort 

pub async fn multipart_abort(
    profile_id: ProfileId,
    bucket: BucketId,
    upload_id: String,
    key: String,
    source: MultipartSource,
    confirmed_unknown: Option<bool>,
    store: State<'_, ProfileStoreHandle>,
    pool: State<'_, S3ClientPoolHandle>,
    multipart_table: State<'_, MultipartTableHandle>,
) -> Result<(), AppError>
Abort a single in-progress multipart upload.

If source == Unknown and confirmed_unknown is not true, returns a Validation error so the frontend must obtain explicit user consent before aborting a foreign upload.

On success with a Brows3r-sourced upload the record is removed from the multipart_active table.