collect_bundle

Function collect_bundle 

pub fn collect_bundle(
    config: &BundleConfig,
    app_paths: &AppPaths,
    redactor: &Redactor,
) -> Result<BundleRef, AppError>
Collect diagnostic files, redact them, zip them, and return a BundleRef.

Creates a temp dir at ${app_cache_dir}/diagnostics/<uuid>/ and writes bundle.zip there. The caller is responsible for eventually cleaning up the temp dir (via export_bundle or explicit cleanup).