dirs_home

Function dirs_home 

fn dirs_home() -> Option<String>
Return the current user’s home directory as a string, without a trailing slash. Returns None when the home directory cannot be determined.