pub fn emit_released<E: EventEmitter>(
channel: &E,
lock: &ResourceLock,
reason: ReleaseReason,
) -> Result<(), AppError>Expand description
Emit lock:released for a lock that was removed with reason.
pub fn emit_released<E: EventEmitter>(
channel: &E,
lock: &ResourceLock,
reason: ReleaseReason,
) -> Result<(), AppError>Emit lock:released for a lock that was removed with reason.