build_menu

Function build_menu 

pub fn build_menu<R: Runtime>(app: &AppHandle<R>) -> Result<Menu<R>>
Build the full application menu and return it.

Returns an error if any menu item or submenu cannot be constructed, which would indicate a Tauri API contract violation (should not happen at runtime).