pub enum SignatureVersion {
V4,
V2,
}Expand description
Signature algorithm used to sign requests for this profile.
V2 is supported as a degraded fallback only for ancient providers
that have not yet adopted SigV4. Using V2 against AWS will fail.
Variants