fn parse_restore_header(header: &str) -> RestoreStatusExpand description
Parse the Glacier restore header string into a RestoreStatus.
S3 uses the form: ongoing-request="true" or
ongoing-request="false", expiry-date="<RFC 2822 date>".
fn parse_restore_header(header: &str) -> RestoreStatusParse the Glacier restore header string into a RestoreStatus.
S3 uses the form: ongoing-request="true" or
ongoing-request="false", expiry-date="<RFC 2822 date>".