pub struct PutResult {
pub etag: Option<String>,
pub last_modified: Option<i64>,
pub version_id: Option<String>,
}Expand description
Result returned by set_object_metadata and set_object_tags.
OCP: checksum: Option<String> and sse_kms_key_id: Option<String> can be
appended as optional fields in a future task without breaking this shape.
Fields
etag: Option<String>ETag of the object after the operation, stripped of surrounding quotes.
last_modified: Option<i64>Unix timestamp in milliseconds of the last-modified time after the op.
version_id: Option<String>Version ID when the bucket has versioning enabled.