pub enum TransferSpec {
Upload {
profile: ProfileId,
bucket: BucketId,
key: String,
source_path: PathBuf,
},
Download {
profile: ProfileId,
bucket: BucketId,
key: String,
dest_path: PathBuf,
},
}Expand description
Discriminated union describing a transfer that can be enqueued into
TransferQueue.
OCP: new kinds (Move, Copy) are added as additional variants here
without touching existing call sites that match on Upload/Download.
Variants