emit_state

Function emit_state 

pub fn emit_state<E: EventEmitter>(
    channel: &E,
    request_id: &str,
    state: TransferState,
) -> Result<(), AppError>
Emit a transfer:state event (unthrottled). Use emit_state_with_error on Failed transitions to attach the underlying AppError to the payload so the frontend can render the failure reason.