async fn revalidate_buckets(
profile_id: ProfileId,
_profile: Profile,
default_region: String,
pool: Arc<ClientPool>,
cache: CacheHandle,
log: Arc<RwLock<NotificationLog>>,
channel: AppHandle,
)Expand description
Re-fetch the bucket list and update the cache + emit events. Called from the background task spawned on a stale cache hit.