pub async fn settings_get(
handle: State<'_, SettingsHandle>,
) -> Result<Settings, AppError>Expand description
Return the current settings as a serialised Settings value.
The frontend can call this on startup to hydrate its settings state.
pub async fn settings_get(
handle: State<'_, SettingsHandle>,
) -> Result<Settings, AppError>Return the current settings as a serialised Settings value.
The frontend can call this on startup to hydrate its settings state.