pub fn current_unix_secs() -> i64
Return current Unix timestamp in seconds.
Separated into a function so tests can substitute a mock clock by calling registry methods directly with a controlled now value.
now