pub fn start_heartbeat_loop<E>(
registry: Arc<LockRegistry>,
interval: Duration,
channel: Arc<E>,
)Expand description
Spawn a tokio task that periodically scans for stale locks and releases them.
The task runs every interval until the process exits (there is no
cancellation token in v1; the task exits when the runtime shuts down).
For each stale lock release_stale is called and a lock:released
event with reason: Ttl is emitted via channel.