pub fn from_display_path(
profile_id: ProfileId,
bucket: BucketId,
segments: &[String],
) -> S3LocationExpand description
Reconstruct an S3Location from breadcrumb segments.
The resulting location has an empty prefix and the joined segments as the
key (or None when segments is empty, indicating the bucket root).